﻿using System;
using System.Windows.Forms;
using System.IO;
using System.Text;
using System.Diagnostics;
using System.Collections.Generic;

//  ProfitUI Quick Raid Buttons tool
//  Copyright (C) 2013 Todd T Knarr <tknarr@silverglass.org> <tknarr@cox.net> <todd.knarr@gmail.com>

//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.

//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.

//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

namespace QuickRaidButtons
{
    static class Program
    {
        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            AppDomain currentDomain = default( AppDomain );
            currentDomain = AppDomain.CurrentDomain;
            // Handler for unhandled exceptions.
            currentDomain.UnhandledException += GlobalUnhandledExceptionHandler;
            // Handler for exceptions in threads behind forms.
            System.Windows.Forms.Application.ThreadException += GlobalThreadExceptionHandler;

            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault( false );

            // Make sure we have a copy of our schema in our AppData folder
            StringBuilder sb = new StringBuilder();
            sb.Append( Environment.GetFolderPath( Environment.SpecialFolder.ApplicationData ) );
            sb.Append( Path.DirectorySeparatorChar );
            sb.Append( Properties.Settings.Default.StorageFolder );
            string SchemaPath = sb.ToString();
            if ( !Directory.Exists( SchemaPath ) )
                Directory.CreateDirectory( SchemaPath );
            sb.Append( Path.DirectorySeparatorChar );
            sb.Append( "QRBStorage.xsd" );
            string SchemaFilename = sb.ToString();
            Debug.WriteLine( "Checking schema file " + SchemaFilename );
            // Update our schema file if the copy in the executable directory's newer than the installed one
            string AppSchemaFilename = Path.GetDirectoryName( Application.ExecutablePath ) + Path.DirectorySeparatorChar + "QRBStorage.xsd";
            if ( !File.Exists( SchemaFilename ) ||
                ( File.GetCreationTime( SchemaFilename ) < File.GetCreationTime( AppSchemaFilename ) ) ||
                ( File.GetLastWriteTime( SchemaFilename ) < File.GetLastWriteTime( AppSchemaFilename ) ) )
            {
                Debug.WriteLine( "Updating schema file from " + AppSchemaFilename );
                File.Copy( AppSchemaFilename, SchemaFilename, true );
            }

            ProfitUICode uicode = new ProfitUICode();
            ButtonAssignment ba = new ButtonAssignment( uicode );
            Application.Run( ba );
        }

        private static void GlobalUnhandledExceptionHandler( object sender, UnhandledExceptionEventArgs e )
        {
            Exception ex = null;
            ex = e.ExceptionObject as Exception;
            LogException( ex );
        }

        private static void GlobalThreadExceptionHandler( object sender, System.Threading.ThreadExceptionEventArgs e )
        {
            Exception ex = null;
            ex = e.Exception;
            LogException( ex );
        }

        private static void LogException( Exception e )
        {
            DateTime now = DateTime.Now;

            StringBuilder sb = new StringBuilder();
            sb.Append( Environment.GetFolderPath( Environment.SpecialFolder.ApplicationData ) );
            sb.Append( Path.DirectorySeparatorChar );
            sb.Append( Properties.Settings.Default.StorageFolder );
            string DumpPath = sb.ToString();
            if ( !Directory.Exists( DumpPath ) )
                Directory.CreateDirectory( DumpPath );
            sb.Append( Path.DirectorySeparatorChar );
            sb.Append( "Crash.log" );
            string DumpFile = sb.ToString();
            File.WriteAllText( DumpFile, now.ToString() + e.ToString() );
        }
    }
}
