﻿using System;
using System.Diagnostics;

//  ProfitUI Quick Raid Buttons tool
//  Copyright (C) 2013 Todd T Knarr <tknarr@silverglass.org> <tknarr@cox.net> <todd.knarr@gmail.com>

//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.

//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.

//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

namespace QuickRaidButtons
{
    // Base class for UI code writers.
    // Right now it's just ProfitUI, but I decided to separate the UI code file handling from the QRB storage to make
    // it easier to support others in the future.
    public abstract class UICode
    {
        // Common properties for all UIs
        // We the the UIPath and UIFilename from the application settings
        public string UIPath { get; set; }
        public string UIFilename { get; set; }
        // Button count will be passed to the constructor, probably by the default constructor for a UI-specific subclass
        public int ButtonCount { get; protected set; }

        public UICode( int bc )
        {
            UIPath = "";
            UIFilename = "";
            ButtonCount = bc;

            if ( !String.IsNullOrEmpty( Properties.Settings.Default.UIFileFolder ) )
                UIPath = Properties.Settings.Default.UIFileFolder;
            else
                UIPath = Environment.GetFolderPath( Environment.SpecialFolder.MyDocuments );
            UIFilename = Properties.Settings.Default.UIFilename;
            Debug.WriteLine( "UI file path: " + UIPath );
            Debug.WriteLine( "UI file name: " + UIFilename );
        }

        // Overridden method to actually generate the UI file for a given UI
        public abstract void saveUICode( QRBStorage qrb );
    }
}
